View source: R/HelperFunctions.R
| collapse_block_diagonal | R Documentation |
Transforms a list of matrices into a single dense block-layout matrix. This is useful especially for quadratic programming problems, where operating on lists of blocks is not convenient.
collapse_block_diagonal(matlist)
matlist |
List of input matrices |
Dense matrix with each input block placed in its own column range
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.