cox_schur_correction: Cox PH Schur Correction

View source: R/cox_helpers.R

cox_schur_correctionR Documentation

Cox PH Schur Correction

Description

Returns zero corrections for all partitions. Cox PH has no nuisance dispersion parameter, so no Schur complement correction to the information matrix is needed. This function exists for interface compatibility with lgspline's schur_correction_function.

Usage

cox_schur_correction(
  X,
  y,
  B,
  dispersion,
  order_list,
  K,
  family,
  observation_weights,
  ...
)

Arguments

X

List of partition design matrices.

y

List of partition response vectors.

B

List of partition coefficient vectors.

dispersion

Dispersion (fixed at 1).

order_list

List of observation indices per partition.

K

Number of knots.

family

Family object.

observation_weights

Observation weights.

...

Additional arguments.

Value

List of K+1 zeros.


lgspline documentation built on May 8, 2026, 5:07 p.m.