dot-compute_dhat_diag: Compute the Derivative of the Tuning Hat Matrix Diagonal

.compute_dhat_diagR Documentation

Compute the Derivative of the Tuning Hat Matrix Diagonal

Description

Computes d h_{ii} / d\lambda_1 partition-wise for the exact leave-one-out tuning criterion.

Usage

.compute_dhat_diag(X, G, dG_dlambda, A, AGAInv, K, p_expansions)

Arguments

X

List of partition-specific design matrices.

G

List of partition-specific \mathbf{G}_k matrices.

dG_dlambda

List of derivatives d\mathbf{G}_k / d\lambda_1.

A

Constraint matrix.

AGAInv

Inverse of \mathbf{A}^{\top}\mathbf{G}\mathbf{A}.

K

Number of interior knots.

p_expansions

Number of columns per partition.

Value

List with dh_diag and dC_list, both partition-wise.


lgspline documentation built on May 8, 2026, 5:07 p.m.