| .tune_grid_search | R Documentation |
Evaluates the selected tuning criterion over a grid of initial wiggle and ridge penalty values to find a good starting point for BFGS optimization.
.tune_grid_search(
log_initial_wiggle,
log_initial_flat,
log_penalty_vec,
criterion_fxn,
env,
include_warnings,
parallel_grideval = TRUE,
cl = NULL,
...
)
log_initial_wiggle |
Numeric vector; log-scale candidate values for the wiggle penalty. |
log_initial_flat |
Numeric vector; log-scale candidate values for the flat ridge penalty. |
log_penalty_vec |
Numeric vector; log-scale predictor/partition penalties. |
criterion_fxn |
Function; tuning-objective evaluation function. |
env |
List; tuning environment. |
include_warnings |
Logical; whether to print warnings on failure. |
... |
Additional arguments passed to |
Numeric vector of length 2; the best (log_wiggle, log_flat) found.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.