grapes-times-times-grapes: Efficient Matrix Multiplication Operator

%**%R Documentation

Efficient Matrix Multiplication Operator

Description

Operator wrapper around C++ efficient_matrix_mult() for matrix multiplication syntax.

This is an internal function meant to provide improvement over base R's operator for certain large matrix operations, at a cost of potential slight slowdown for smaller problems.

Usage

x %**% y

Arguments

x

Left matrix

y

Right matrix

Value

Matrix product of x and y

Examples


M1 <- matrix(1:4, 2, 2)
M2 <- matrix(5:8, 2, 2)
M1 %**% M2



lgspline documentation built on Aug. 5, 2026, 1:10 a.m.