| lgspline-methods | R Documentation |
Allows for common S3 methods including print, summary, coef, plot, and predict, with additional inference methods provided.
This package implements various methods for working with lgspline models, including printing, summarizing, plotting, and conducting statistical inference.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.