| matmult_U | R Documentation |
Useful for computing UG where G is a list of block-diagonal matrices for each partition, and U is a square P by P dense matrix
matmult_U(U, G, nc, K)
U |
Matrix of dimension P by P that projects onto the null space of A transpose |
G |
List of G matrices for each partition |
nc |
Numeric numeric of basis expansions of predictors per partition |
K |
Number of blocks |
Matrix of UG
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.