Print Method for lgspline Object Summaries
# S3 method for summary.lgspline
print(x, ...)Invisibly returns the original summary.lgspline object x.
Like other print methods, this function is called to display a formatted
summary of the fitted lgspline model to the console.
This includes model dimensions, family information, dispersion estimate,
effective degrees of freedom, and a coefficient table for univariate inference
(if available) analogous to output from summary.glm.
A summary.lgspline object, the result of calling summary() on an lgspline object.
Not used.