View source: R/HelperFunctions.R View source: R/HelperFunctions.R
| compute_G_eigen | R Documentation |
Computes partition-wise inverse-information matrices and their matrix square roots from the penalized information matrix via eigendecomposition.
Computes partition-wise inverse-information matrices and their matrix square roots from the penalized information matrix via eigendecomposition.
compute_G_eigen(
X_gram,
Lambda,
K,
parallel,
cl,
chunk_size,
num_chunks,
rem_chunks,
family,
unique_penalty_per_partition,
L_partition_list,
keep_G = TRUE,
schur_corrections
)
compute_G_eigen(
X_gram,
Lambda,
K,
parallel,
cl,
chunk_size,
num_chunks,
rem_chunks,
family,
unique_penalty_per_partition,
L_partition_list,
keep_G = TRUE,
schur_corrections
)
X_gram |
List of Gram matrices |
Lambda |
Penalty matrix |
K |
Integer; number of interior knots (partitions = |
parallel |
Logical; use parallel processing across partitions. |
cl |
Cluster object from |
chunk_size, num_chunks, rem_chunks |
Partition distribution parameters. |
family |
GLM family object. |
unique_penalty_per_partition |
Logical; if |
L_partition_list |
List of partition-specific penalty matrices. |
keep_G |
Logical; if |
schur_corrections |
List of Schur complement correction matrices. |
A list with components G (or NULL blocks when
keep_G = FALSE), Ghalf, and optionally GhalfInv.
A list with components G (or NULL blocks when
keep_G = FALSE), Ghalf, and optionally GhalfInv.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.