| .active_set_refine_full | R Documentation |
Reuses the generic add/drop active-set controller but evaluates each
equality subproblem with the exact full \mathbf{G}^{1/2}. This keeps
dense QP as a fallback while avoiding multiplier sign errors from using
only diagonal blocks of a full correlated square root.
.active_set_refine_full(
result,
K,
p_expansions,
A,
constraint_value_vectors,
family,
qp_Amat,
qp_bvec,
qp_meq,
rhs_full,
Ghalf_full,
tol,
parallel_qr = FALSE,
cl = NULL,
max_as_iter = NULL,
initial_active_ineq = integer(0),
method = "active_set_full"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.